@@ -7,7 +7,7 @@ function(obj,var,extrapolation = c("linear", "quadratic", "both"),ylimit) {
 
   y = apply(obj$theta[[var]],2,mean)
 
-  plot(x,y,type ="p",xlim=c(-1.5,max(x)),ylim=ylimit,xlab="lambda",ylab=var,col ="green",pch =19)
+  plot(x,y,type ="p",xlim=c(-1.5,max(x)),ylim=ylimit, xlab="Magnitude of Measurement Error", ylab="Estimated Coefficient", main = substitute(paste("Extrapolation Effect on ", var)),col ="green",pch =19)
 
   new = data.frame(x = seq(-1.2,2,0.2))
   
